@@ -4,6 +4,7 @@ from setuptools_scm import git
 import pytest
 from datetime import date
 from os.path import join as opj
+from setuptools_scm.file_finder_git import git_find_files
 
 
 @pytest.fixture
@@ -28,6 +29,14 @@ def test_parse_describe_output(given, tag, number, node, dirty):
     assert parsed == (tag, number, node, dirty)
 
 
+@pytest.mark.issue("https://github.com/pypa/setuptools_scm/issues/298")
+def test_file_finder_no_history(wd, caplog):
+    file_list = git_find_files(str(wd.cwd))
+    assert file_list == []
+
+    assert "listing git files failed - pretending there aren't any" in caplog.text
+
+
 @pytest.mark.issue("https://github.com/pypa/setuptools_scm/issues/281")
 def test_parse_call_order(wd):
     git.parse(str(wd.cwd), git.DEFAULT_DESCRIBE)
@@ -54,7 +63,10 @@ def test_version_from_git(wd):
 
     wd.commit_testfile()
     wd("git tag version-0.2.post210+gbe48adfpost3+g0cc25f2")
-    assert wd.version.startswith("0.2")
+    with pytest.warns(
+        UserWarning, match="tag '.*' will be stripped of its suffix '.*'"
+    ):
+        assert wd.version.startswith("0.2")
 
     wd.commit_testfile()
     wd("git tag 17.33.0-rc")
